@@ -63,15 +63,23 @@ sub get_sub_write_scalar {
         print $fh $c,"\n\n";
     };
 
-    return ($write_sub, \$o->{write_scalar});
+    my $end_sub = sub {
+        return (
+            \$o->{write_scalar}, 
+            writer => $index_ref->{writer}, 
+            book => $index_ref->{book}
+        );
+    };
+
+    return ($write_sub, $end_sub);
 }
 
 sub get_sub_write_file {
     my ($self, $index_ref, $o) = @_;
 
     my $fname = $self->format_filename($index_ref, $o);
-    open my $fh, '>:utf8', $fname;
 
+    open my $fh, '>:utf8', $fname;
     my $write_sub = sub {
         my ($c) = @_;
         print $fh $c,"\n\n";
